Tutorials
=========

The following introductory tutorial will help you get started with ``21cmfish``
to create a Fisher matrix from 21cmFAST lightcones:

.. toctree::
   :maxdepth: 2

   tutorials/fisher_examples
